@@ -3,13 +3,12 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use Moo;
 use strictures 2;
 
 use DBI;
-use File::Basename;
 use File::Copy;
 use File::Temp qw/ tempfile /;
 
@@ -44,7 +43,7 @@ has dbh => (
 
 sub _build_dbh {
     my ($self) = @_;
-    return DBI->connect( 'dbi:SQLite:dbname=' . $self->_database->filename, '', '' );
+    return DBI->connect( $self->dsn, '', '' );
 }
 
 has _database => (
@@ -90,7 +89,6 @@ sub _build__database {
 
 sub BUILD {
     my ( $self, $args ) = @_;
-
     die 'Schema and database may not be used at the same time.'
         if $self->database and $self->schema;
 }
@@ -109,7 +107,7 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -120,12 +118,12 @@ version 0.0100
     database => '/some/where/production.db',
   );
 
+  my $dbh = DBI->connect($sqlite->dsn, '', '');
+
   $sqlite = Test::SQLite->new(
     schema => '/some/where/schema.sql',
   );
 
-  my $dbh = DBI->connect($sqlite->dsn, '', '');
-
   $dbh = $sqlite->dbh;
 
 =head1 DESCRIPTION
@@ -169,7 +167,7 @@ A connected database handle.
 
 =head2 new
 
-  $x = Test::SQLite->new(%arguments);
+  $sqlite = Test::SQLite->new(%arguments);
 
 Create a new C<Test::SQLite> object.
 
@@ -185,8 +183,6 @@ Kaitlyn Parkhurst <symkat@symkat.com>
 
 L<DBI>
 
-L<File::Basename>
-
 L<File::Copy>
 
 L<File::Temp>
